/*******************************************************************************
* File Name: TP.c  
* Version 2.20
*
* Description:
*  This file contains APIs to set up the Pins component for low power modes.
*
* Note:
*
********************************************************************************
* Copyright 2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "TP.h"

static TP_BACKUP_STRUCT  TP_backup = {0u, 0u, 0u};


/*******************************************************************************
* Function Name: TP_Sleep
****************************************************************************//**
*
* \brief Stores the pin configuration and prepares the pin for entering chip 
*  deep-sleep/hibernate modes. This function must be called for SIO and USBIO
*  pins. It is not essential if using GPIO or GPIO_OVT pins.
*
* <b>Note</b> This function is available in PSoC 4 only.
*
* \return 
*  None 
*  
* \sideeffect
*  For SIO pins, this function configures the pin input threshold to CMOS and
*  drive level to Vddio. This is needed for SIO pins when in device 
*  deep-sleep/hibernate modes.
*
* \funcusage
*  \snippet TP_SUT.c usage_TP_Sleep_Wakeup
*******************************************************************************/
void TP_Sleep(void)
{
    #if defined(TP__PC)
        TP_backup.pcState = TP_PC;
    #else
        #if (CY_PSOC4_4200L)
            /* Save the regulator state and put the PHY into suspend mode */
            TP_backup.usbState = TP_CR1_REG;
            TP_USB_POWER_REG |= TP_USBIO_ENTER_SLEEP;
            TP_CR1_REG &= TP_USBIO_CR1_OFF;
        #endif
    #endif
    #if defined(CYIPBLOCK_m0s8ioss_VERSION) && defined(TP__SIO)
        TP_backup.sioState = TP_SIO_REG;
        /* SIO requires unregulated output buffer and single ended input buffer */
        TP_SIO_REG &= (uint32)(~TP_SIO_LPM_MASK);
    #endif  
}


/*******************************************************************************
* Function Name: TP_Wakeup
****************************************************************************//**
*
* \brief Restores the pin configuration that was saved during Pin_Sleep().
*
* For USBIO pins, the wakeup is only triggered for falling edge interrupts.
*
* <b>Note</b> This function is available in PSoC 4 only.
*
* \return 
*  None
*  
* \funcusage
*  Refer to TP_Sleep() for an example usage.
*******************************************************************************/
void TP_Wakeup(void)
{
    #if defined(TP__PC)
        TP_PC = TP_backup.pcState;
    #else
        #if (CY_PSOC4_4200L)
            /* Restore the regulator state and come out of suspend mode */
            TP_USB_POWER_REG &= TP_USBIO_EXIT_SLEEP_PH1;
            TP_CR1_REG = TP_backup.usbState;
            TP_USB_POWER_REG &= TP_USBIO_EXIT_SLEEP_PH2;
        #endif
    #endif
    #if defined(CYIPBLOCK_m0s8ioss_VERSION) && defined(TP__SIO)
        TP_SIO_REG = TP_backup.sioState;
    #endif
}


/* [] END OF FILE */
