/*******************************************************************************
* File Name: Test123.c  
* Version 2.20
*
* Description:
*  This file contains APIs to set up the Pins component for low power modes.
*
* Note:
*
********************************************************************************
* Copyright 2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "Test123.h"

static Test123_BACKUP_STRUCT  Test123_backup = {0u, 0u, 0u};


/*******************************************************************************
* Function Name: Test123_Sleep
****************************************************************************//**
*
* \brief Stores the pin configuration and prepares the pin for entering chip 
*  deep-sleep/hibernate modes. This function must be called for SIO and USBIO
*  pins. It is not essential if using GPIO or GPIO_OVT pins.
*
* <b>Note</b> This function is available in PSoC 4 only.
*
* \return 
*  None 
*  
* \sideeffect
*  For SIO pins, this function configures the pin input threshold to CMOS and
*  drive level to Vddio. This is needed for SIO pins when in device 
*  deep-sleep/hibernate modes.
*
* \funcusage
*  \snippet Test123_SUT.c usage_Test123_Sleep_Wakeup
*******************************************************************************/
void Test123_Sleep(void)
{
    #if defined(Test123__PC)
        Test123_backup.pcState = Test123_PC;
    #else
        #if (CY_PSOC4_4200L)
            /* Save the regulator state and put the PHY into suspend mode */
            Test123_backup.usbState = Test123_CR1_REG;
            Test123_USB_POWER_REG |= Test123_USBIO_ENTER_SLEEP;
            Test123_CR1_REG &= Test123_USBIO_CR1_OFF;
        #endif
    #endif
    #if defined(CYIPBLOCK_m0s8ioss_VERSION) && defined(Test123__SIO)
        Test123_backup.sioState = Test123_SIO_REG;
        /* SIO requires unregulated output buffer and single ended input buffer */
        Test123_SIO_REG &= (uint32)(~Test123_SIO_LPM_MASK);
    #endif  
}


/*******************************************************************************
* Function Name: Test123_Wakeup
****************************************************************************//**
*
* \brief Restores the pin configuration that was saved during Pin_Sleep().
*
* For USBIO pins, the wakeup is only triggered for falling edge interrupts.
*
* <b>Note</b> This function is available in PSoC 4 only.
*
* \return 
*  None
*  
* \funcusage
*  Refer to Test123_Sleep() for an example usage.
*******************************************************************************/
void Test123_Wakeup(void)
{
    #if defined(Test123__PC)
        Test123_PC = Test123_backup.pcState;
    #else
        #if (CY_PSOC4_4200L)
            /* Restore the regulator state and come out of suspend mode */
            Test123_USB_POWER_REG &= Test123_USBIO_EXIT_SLEEP_PH1;
            Test123_CR1_REG = Test123_backup.usbState;
            Test123_USB_POWER_REG &= Test123_USBIO_EXIT_SLEEP_PH2;
        #endif
    #endif
    #if defined(CYIPBLOCK_m0s8ioss_VERSION) && defined(Test123__SIO)
        Test123_SIO_REG = Test123_backup.sioState;
    #endif
}


/* [] END OF FILE */
