/* ========================================
 *
 * https://www.hackster.io/holger/cywordclock-time-goes-slowly-psoc-4-ble-588723
 *
 * Holger.Wech@gmx.de
 *
 * v2017-12-13
 *  - Color setting u32ColFUENFZEHNVOR corrected
 *  - Manual dimming added
 *
 * ========================================
*/
#include "project.h"
#include "main.h"
#include "led.h"
#include "cydisabledsheets.h"
#include "BLEProcess.h"

#ifndef DCF77__DISABLED
    #include "dcf77.h"
    #include "dcf77.c"
#endif    

// In order to debug the ADC value by LEDs (1,2,3,4) instead of UART #define DEBUG_ADC_2_LED
//#define DEBUG_ADC_2_LED

// Brighness
#define LED_BRIGHTNESS_DEFAULT 1 // uswed as default if not ADC is enabled
 
uint8_t u8DimMode;   // 0: max, ..., 4:min, 5:Auto (LightResistor)
uint8_t u8LightDim1; // Limit when Light ADC value will force DIM=1 
uint8_t u8LightDim2; // Limit when Light ADC value will force DIM=2
uint8_t u8LightDim3; // Limit when Light ADC value will force DIM=3


#ifndef UART__DISABLED
    #include <stdio.h>
    #include <stdlib.h>
    #include <strings.h>
    char szPrintf[32]; // buffer used for sprintf
#endif




CY_ISR_PROTO(Clock1HzIsr);      // Timer ISR
volatile uint32_t u32MyTime;    // keeps the actual time

CY_ISR_PROTO(mySystick_ISR);    // Konfigured as 100ms timer tick = 0.1ms * 24MHz = 2.400.000
#define NUMBER_OF_TICKS		 2400000

uint8_t u8ClockSet; // Set to 1 if the time has been set by BLE or DCF77

uint8_t flagLEDr, flagLEDg;    // used for debugging / blinking

uint8 sec;
uint8 min;
uint8 hour;
uint8  UhrzeitUpdate;
uint8 day;
uint8 hour24;
uint8  AlarmON;
uint8  CapsON;

// BLE characteristic ‚Alarmsetting‘ 0003C005-0000-1000-8000-00805F9B0131
uint8 MyBleWordClockAlarm[14]; // HH: Sunday, MM: Sunday, HH: Monday, MM: Monday, HH: Tuesday, ...
                               // if MSB(HH) then Alarm is enabled

// BLE characteristic ‚Kalender‘ 0003C002-0000-1000-8000-00805F9B0131
uint8 MyBleWordClockCalendar[CY_WORDCLOCK_CALENDAR_LEN]; 

// [0] : mode -> 0: Set complete Time MyBleWordClockCalendar[1..7]
//               1: Restore preset color scheme defined by MyBleWordClockCalendar[1]
//               2: Save current colors to preset memory defined by MyBleWordClockCalendar[1]
//               3: Set all colors to value of MyBleWordClockCalendar[1]
// [1] : mode=0:HH, mode=1 or 2: Preset buffer, mode=3: Set all LEDs to this color
// [2] : MM
// [3] : SS
// [4] : DD
// [5] : MM
// [6] : YR
// [7] : YR
// [8] : rsvd 
// [9] : rsvd

// BLE characteristic ‚Farbsatz1‘ 0003C003-0000-1000-8000-00805F9B0131
uint8 MyBleWordClockColor1[CY_WORDCLOCK_COLOR_LEN1]; 

// [0]  : u32ColEs;
// [1]  : u32ColIst;
// [2]  : u32ColGenau;
// [3]  : u32ColFuenf0;
// [4]  : u32ColZehn0;
// [5]  : u32ColFuenfzehn0;
// [6]  : u32ColVor;
// [7]  : u32ColNach;
// [8]  : u32ColHalb;
// [9]  : u32ColMinuten
// [10] : u32ColUhr;

// BLE characteristic ‚Farbsatz2‘ 0003C004-0000-1000-8000-00805F9B0131
uint8 MyBleWordClockColor2[CY_WORDCLOCK_COLOR_LEN2]; 

// [0]  : u32ColEins;
// [1]  : u32ColZwei;
// [2]  : u32ColDrei;
// [3]  : u32ColVier;
// [4]  : u32ColFuenf;
// [5]  : u32ColSechs;
// [6]  : u32ColSieben;
// [7]  : u32ColAcht;
// [8]  : u32ColNeun;
// [9]  : u32ColZehn;
// [10] : u32ColElf;
// [11] : u32ColZwoelf;

uint32 u32ColES;
uint32 u32ColIST;
uint32 u32ColGENAU;
uint32 u32ColFUENFVOR;
uint32 u32ColZEHNVOR;
uint32 u32ColFUENFZEHNVOR;
uint32 u32ColVOR;
uint32 u32ColNACH;
uint32 u32ColHALB;
uint32 u32ColMIN;
uint32 u32ColEINSMIN;
uint32 u32ColZWEIMIN;
uint32 u32ColDREIMIN;
uint32 u32ColVIERMIN;
uint32 u32ColUHR;

uint32 u32ColEIN;
uint32 u32ColZWEI;
uint32 u32ColDREI;
uint32 u32ColVIER;
uint32 u32ColFUENF;
uint32 u32ColSECHS;
uint32 u32ColSIEBEN;
uint32 u32ColACHT;
uint32 u32ColNEUN;
uint32 u32ColZEHN;
uint32 u32ColELF;
uint32 u32ColZWOELF;

uint32_t MyColorPreset[5][23] = { 
    
    { // Preset [0] - - b b r r g g (weiss)
        0x00FFFFFF, 
        0x00FFFFFF, 
        0x00FFFFFF, 
        0x00FFFFFF, 
        0x00FFFFFF, 
        0x00FFFFFF, 
        0x00FFFFFF, 
        0x00FFFFFF, 
        0x00FFFFFF, 
        0x00FFFFFF, 
        0x00FFFFFF, 
        0x00FFFFFF, 
        0x00FFFFFF, 
        0x00FFFFFF, 
        0x00FFFFFF, 
        0x00FFFFFF, 
        0x00FFFFFF, 
        0x00FFFFFF, 
        0x00FFFFFF, 
        0x00FFFFFF, 
        0x00FFFFFF, 
        0x00FFFFFF, 
        0x00FFFFFF 
    }, 
    { // Preset [1] - - b b r r g g (rot)
        0x0000FF00, 
        0x0000FF00, 
        0x0000FF00, 
        0x0000FF00, 
        0x0000FF00, 
        0x0000FF00, 
        0x0000FF00, 
        0x0000FF00, 
        0x0000FF00, 
        0x0000FF00, 
        0x0000FF00, 
        0x0000FF00, 
        0x0000FF00, 
        0x0000FF00, 
        0x0000FF00, 
        0x0000FF00, 
        0x0000FF00, 
        0x0000FF00, 
        0x0000FF00, 
        0x0000FF00, 
        0x0000FF00, 
        0x0000FF00, 
        0x0000FF00 
    }, 
    { // Preset [2] - - b b r r g g (gruen)
        0x000000FF, 
        0x000000FF, 
        0x000000FF, 
        0x000000FF, 
        0x000000FF, 
        0x000000FF, 
        0x000000FF, 
        0x000000FF, 
        0x000000FF, 
        0x000000FF, 
        0x000000FF, 
        0x000000FF, 
        0x000000FF, 
        0x000000FF, 
        0x000000FF, 
        0x000000FF, 
        0x000000FF, 
        0x000000FF, 
        0x000000FF, 
        0x000000FF, 
        0x000000FF, 
        0x000000FF, 
        0x000000FF 
    }, 
    { // Preset [3] - - b b r r g g (blau)
        0x00FF0000, 
        0x00FF0000, 
        0x00FF0000, 
        0x00FF0000, 
        0x00FF0000, 
        0x00FF0000, 
        0x00FF0000, 
        0x00FF0000, 
        0x00FF0000, 
        0x00FF0000, 
        0x00FF0000, 
        0x00FF0000, 
        0x00FF0000, 
        0x00FF0000, 
        0x00FF0000, 
        0x00FF0000, 
        0x00FF0000, 
        0x00FF0000, 
        0x00FF0000, 
        0x00FF0000, 
        0x00FF0000, 
        0x00FF0000, 
        0x00FF0000 
    }, 
    { // Preset [4] - - b b r r g g (gelb)
        0x000000FF, 
        0x000000FF, 
        0x00FFFFFF, 
        0x00FF0000, 
        0x00FF0000, 
        0x00FF0000, 
        0x00FF0000, 
        0x00FF0000, 
        0x00FF0000, 
        0x00FFFF00, 
        0x000000FF, 
        0x0000FF00, 
        0x0000FF00, 
        0x0000FF00, 
        0x0000FF00, 
        0x0000FF00, 
        0x0000FF00, 
        0x0000FF00, 
        0x0000FF00, 
        0x0000FF00, 
        0x0000FF00, 
        0x0000FF00, 
        0x0000FF00 
    }
};

void ColorPresetRead(uint8_t channel)
{
    if (channel < 5)
    {
        u32ColES           = MyColorPreset[channel][0];
        u32ColIST          = MyColorPreset[channel][1];
        u32ColGENAU        = MyColorPreset[channel][2];
        u32ColFUENFVOR     = MyColorPreset[channel][3];
        u32ColZEHNVOR      = MyColorPreset[channel][4];
        u32ColFUENFZEHNVOR = MyColorPreset[channel][5];
        u32ColVOR          = MyColorPreset[channel][6];
        u32ColNACH         = MyColorPreset[channel][7];
        u32ColHALB         = MyColorPreset[channel][8];
        u32ColEINSMIN      = MyColorPreset[channel][9];
        u32ColZWEIMIN      = MyColorPreset[channel][9];
        u32ColDREIMIN      = MyColorPreset[channel][9];
        u32ColVIERMIN      = MyColorPreset[channel][9];
        u32ColMIN          = MyColorPreset[channel][9];
        u32ColUHR          = MyColorPreset[channel][10];
            
        u32ColEIN          = MyColorPreset[channel][11];
        u32ColZWEI         = MyColorPreset[channel][12];
        u32ColDREI         = MyColorPreset[channel][13];
        u32ColVIER         = MyColorPreset[channel][14];
        u32ColFUENF        = MyColorPreset[channel][15];
        u32ColSECHS        = MyColorPreset[channel][16];
        u32ColSIEBEN       = MyColorPreset[channel][17];
        u32ColACHT         = MyColorPreset[channel][18];
        u32ColNEUN         = MyColorPreset[channel][19];
        u32ColZEHN         = MyColorPreset[channel][20];
        u32ColELF          = MyColorPreset[channel][21];
        u32ColZWOELF       = MyColorPreset[channel][22];
    }
}

void ColorPresetWrite(uint8_t channel)
{
    if (channel < 5)
    {
        MyColorPreset[channel][0]  = u32ColES;
        MyColorPreset[channel][1]  = u32ColIST;
        MyColorPreset[channel][2]  = u32ColGENAU;
        MyColorPreset[channel][3]  = u32ColFUENFVOR;
        MyColorPreset[channel][4]  = u32ColZEHNVOR;
        MyColorPreset[channel][5]  = u32ColFUENFZEHNVOR;
        MyColorPreset[channel][6]  = u32ColVOR;
        MyColorPreset[channel][7]  = u32ColNACH;
        MyColorPreset[channel][8]  = u32ColHALB;
        //MyColorPreset[channel][9]  = u32ColEINSMIN;
        //MyColorPreset[channel][9]  = u32ColZWEIMIN;
        //MyColorPreset[channel][9]  = u32ColDREIMIN;
        //MyColorPreset[channel][9]  = u32ColVIERMIN;
        MyColorPreset[channel][9]  = u32ColMIN;
        MyColorPreset[channel][10] = u32ColUHR;
                                     
        MyColorPreset[channel][11] = u32ColEIN;
        MyColorPreset[channel][12] = u32ColZWEI;
        MyColorPreset[channel][13] = u32ColDREI;
        MyColorPreset[channel][14] = u32ColVIER;
        MyColorPreset[channel][15] = u32ColFUENF;
        MyColorPreset[channel][16] = u32ColSECHS;
        MyColorPreset[channel][17] = u32ColSIEBEN;
        MyColorPreset[channel][18] = u32ColACHT;
        MyColorPreset[channel][19] = u32ColNEUN;
        MyColorPreset[channel][20] = u32ColZEHN;
        MyColorPreset[channel][21] = u32ColELF;
        MyColorPreset[channel][22] = u32ColZWOELF;
    }
}

uint8_t Color2Byte(uint32_t color)
{
  return ( ((color & 0x0000C000) >> 10) + ((color & 0x000000C0) >> 4) + ((color & 0x00C00000) >> 22) );
}

void UpdateColor2BLE()
{
  MyBleWordClockColor1[0]  = Color2Byte(u32ColES);
  MyBleWordClockColor1[1]  = Color2Byte(u32ColIST);
  MyBleWordClockColor1[2]  = Color2Byte(u32ColGENAU);
  MyBleWordClockColor1[3]  = Color2Byte(u32ColFUENFVOR);
  MyBleWordClockColor1[4]  = Color2Byte(u32ColZEHNVOR);
  MyBleWordClockColor1[5]  = Color2Byte(u32ColFUENFZEHNVOR);
  MyBleWordClockColor1[6]  = Color2Byte(u32ColVOR);
  MyBleWordClockColor1[7]  = Color2Byte(u32ColNACH);
  MyBleWordClockColor1[8]  = Color2Byte(u32ColHALB);
  MyBleWordClockColor1[9]  = Color2Byte(u32ColMIN);
  MyBleWordClockColor1[10] = Color2Byte(u32ColUHR);

  MyBleWordClockColor2[0]  = Color2Byte(u32ColEIN); 
  MyBleWordClockColor2[1]  = Color2Byte(u32ColZWEI);
  MyBleWordClockColor2[2]  = Color2Byte(u32ColDREI);
  MyBleWordClockColor2[3]  = Color2Byte(u32ColVIER);
  MyBleWordClockColor2[4]  = Color2Byte(u32ColFUENF);
  MyBleWordClockColor2[5]  = Color2Byte(u32ColSECHS);
  MyBleWordClockColor2[6]  = Color2Byte(u32ColSIEBEN);
  MyBleWordClockColor2[7]  = Color2Byte(u32ColACHT);
  MyBleWordClockColor2[8]  = Color2Byte(u32ColNEUN);
  MyBleWordClockColor2[9]  = Color2Byte(u32ColZEHN);
  MyBleWordClockColor2[10] = Color2Byte(u32ColELF);
  MyBleWordClockColor2[11] = Color2Byte(u32ColZWOELF);
}

uint32_t Byte2Color(uint8_t color)
{
  return (   ((color & 0x30) << 10) 
           + ((color & 0x30) << 8) 
           + ((color & 0x30) << 6) 
           + ((color & 0x30) << 4) 
         
           + ((color & 0x0C) << 4) 
           + ((color & 0x0C) << 2) 
           + ((color & 0x0C) << 0) 
           + ((color & 0x0C) >> 2) 

           + ((color & 0x03) << 22) 
           + ((color & 0x03) << 20) 
           + ((color & 0x03) << 18) 
           + ((color & 0x03) << 16) 
         );
}

void UpdateBLE2Color()
{
  u32ColES              = Byte2Color(MyBleWordClockColor1[0]);
  u32ColIST             = Byte2Color(MyBleWordClockColor1[1]); 
  u32ColGENAU           = Byte2Color(MyBleWordClockColor1[2]); 
  u32ColFUENFVOR        = Byte2Color(MyBleWordClockColor1[3]); 
  u32ColZEHNVOR         = Byte2Color(MyBleWordClockColor1[4]); 
  u32ColFUENFZEHNVOR    = Byte2Color(MyBleWordClockColor1[5]); 
  u32ColVOR             = Byte2Color(MyBleWordClockColor1[6]); 
  u32ColNACH            = Byte2Color(MyBleWordClockColor1[7]); 
  u32ColHALB            = Byte2Color(MyBleWordClockColor1[8]); 
  u32ColMIN             = Byte2Color(MyBleWordClockColor1[9]); 
  u32ColEINSMIN         = Byte2Color(MyBleWordClockColor1[9]); 
  u32ColZWEIMIN         = Byte2Color(MyBleWordClockColor1[9]); 
  u32ColDREIMIN         = Byte2Color(MyBleWordClockColor1[9]); 
  u32ColVIERMIN         = Byte2Color(MyBleWordClockColor1[9]); 

  u32ColUHR     = Byte2Color(MyBleWordClockColor1[10]); 
                                            
  u32ColEIN     = Byte2Color(MyBleWordClockColor2[0]);
  u32ColZWEI    = Byte2Color(MyBleWordClockColor2[1]); 
  u32ColDREI    = Byte2Color(MyBleWordClockColor2[2]); 
  u32ColVIER    = Byte2Color(MyBleWordClockColor2[3]); 
  u32ColFUENF   = Byte2Color(MyBleWordClockColor2[4]); 
  u32ColSECHS   = Byte2Color(MyBleWordClockColor2[5]); 
  u32ColSIEBEN  = Byte2Color(MyBleWordClockColor2[6]); 
  u32ColACHT    = Byte2Color(MyBleWordClockColor2[7]); 
  u32ColNEUN    = Byte2Color(MyBleWordClockColor2[8]); 
  u32ColZEHN    = Byte2Color(MyBleWordClockColor2[9]); 
  u32ColELF     = Byte2Color(MyBleWordClockColor2[10]); 
  u32ColZWOELF  = Byte2Color(MyBleWordClockColor2[11]);
}

/* ========================================
 * WS2812 related
 * ========================================
*/
extern const uint32 StripLights_CLUT[ ];

// WS2812B 4x4
//
// -  0 1 2 3 
// +  7 6 5 4    
// >  8 9 A B
// -  F E D C

// The following functions will set all LEDs per clock word
// The color of each word is given by the parameter

void wcES (uint32 color)
{
  StripLights_Pixel(0,0, color); // - - b b r r g g 
  StripLights_Pixel(1,0, color); // - - b b r r g g 
}
 
void wcIST(uint32 color)
{
  StripLights_Pixel(3,0, color); // - - b b r r g g 
  StripLights_Pixel(16,0, color); // - - b b r r g g 
  StripLights_Pixel(17,0, color); // - - b b r r g g 
}

void wcGENAU (uint32 color)
{
  StripLights_Pixel(19,0, color); // - - b b r r g g 
  StripLights_Pixel(32,0, color); // - - b b r r g g 
  StripLights_Pixel(33,0, color); // - - b b r r g g 
  StripLights_Pixel(34,0, color); // - - b b r r g g 
  StripLights_Pixel(35,0, color); // - - b b r r g g 
}

void wcFUENFVOR (uint32 color)
{
  StripLights_Pixel(7,0, color); // - - b b r r g g 
  StripLights_Pixel(6,0, color); // - - b b r r g g 
  StripLights_Pixel(5,0, color); // - - b b r r g g 
  StripLights_Pixel(4,0, color); // - - b b r r g g 
}

void wcZEHNVOR (uint32 color)
{
  StripLights_Pixel(23,0, color); // - - b b r r g g 
  StripLights_Pixel(22,0, color); // - - b b r r g g 
  StripLights_Pixel(21,0, color); // - - b b r r g g 
  StripLights_Pixel(20,0, color); // - - b b r r g g 
}

void wcFUENFZEHNVOR (uint32 color)
{
  StripLights_Pixel(7,0, color); // - - b b r r g g 
  StripLights_Pixel(6,0, color); // - - b b r r g g 
  StripLights_Pixel(5,0, color); // - - b b r r g g 
  StripLights_Pixel(4,0, color); // - - b b r r g g 
  StripLights_Pixel(23,0, color); // - - b b r r g g 
  StripLights_Pixel(22,0, color); // - - b b r r g g 
  StripLights_Pixel(21,0, color); // - - b b r r g g 
  StripLights_Pixel(20,0, color); // - - b b r r g g 
}

void wcVOR (uint32 color)
{
  StripLights_Pixel(38,0, color); // - - b b r r g g 
  StripLights_Pixel(37,0, color); // - - b b r r g g 
  StripLights_Pixel(36,0, color); // - - b b r r g g 
}

void wcNACH (uint32 color)
{
  StripLights_Pixel(9,0, color); // - - b b r r g g 
  StripLights_Pixel(10,0, color); // - - b b r r g g 
  StripLights_Pixel(11,0, color); // - - b b r r g g 
  StripLights_Pixel(24,0, color); // - - b b r r g g 
}

void wcHALB (uint32 color)
{
  StripLights_Pixel(26,0, color); // - - b b r r g g 
  StripLights_Pixel(27,0, color); // - - b b r r g g 
  StripLights_Pixel(40,0, color); // - - b b r r g g 
  StripLights_Pixel(41,0, color); // - - b b r r g g 
}

void wcEIN (uint32 color)
{
  StripLights_Pixel(95,0, color); // - - b b r r g g 
  StripLights_Pixel(76,0, color); // - - b b r r g g 
  StripLights_Pixel(77,0, color); // - - b b r r g g 
   
  
}
void wcS (uint32 color)
{
  StripLights_Pixel(78,0, color); // - - b b r r g g
}

void wcZWEI (uint32 color)
{
  StripLights_Pixel(93,0, color); // - - b b r r g g 
  StripLights_Pixel(94,0, color); // - - b b r r g g 
  StripLights_Pixel(95,0, color); // - - b b r r g g 
  StripLights_Pixel(76,0, color); // - - b b r r g g 
}

void wcDREI (uint32 color)
{
  StripLights_Pixel(91,0, color); // - - b b r r g g 
  StripLights_Pixel(90,0, color); // - - b b r r g g 
  StripLights_Pixel(89,0, color); // - - b b r r g g 
  StripLights_Pixel(88,0, color); // - - b b r r g g 
}

void wcVIER (uint32 color)
{
  StripLights_Pixel(47,0, color); // - - b b r r g g 
  StripLights_Pixel(46,0, color); // - - b b r r g g 
  StripLights_Pixel(45,0, color); // - - b b r r g g 
  StripLights_Pixel(44,0, color); // - - b b r r g g 
}

void wcFUENF (uint32 color)
{
  StripLights_Pixel(31,0, color); // - - b b r r g g 
  StripLights_Pixel(30,0, color); // - - b b r r g g 
  StripLights_Pixel(29,0, color); // - - b b r r g g 
  StripLights_Pixel(28,0, color); // - - b b r r g g 
}

void wcSECHS (uint32 color)
{
  StripLights_Pixel(75,0, color); // - - b b r r g g 
  StripLights_Pixel(74,0, color); // - - b b r r g g 
  StripLights_Pixel(73,0, color); // - - b b r r g g 
  StripLights_Pixel(72,0, color); // - - b b r r g g 
  StripLights_Pixel(59,0, color); // - - b b r r g g 
}

void wcSIEBEN (uint32 color)
{
  StripLights_Pixel(78,0, color); // - - b b r r g g 
  StripLights_Pixel(79,0, color); // - - b b r r g g 
  StripLights_Pixel(60,0, color); // - - b b r r g g 
  StripLights_Pixel(61,0, color); // - - b b r r g g 
  StripLights_Pixel(62,0, color); // - - b b r r g g 
  StripLights_Pixel(63,0, color); // - - b b r r g g 
}

void wcACHT (uint32 color)
{
  StripLights_Pixel(84,0, color); // - - b b r r g g 
  StripLights_Pixel(85,0, color); // - - b b r r g g 
  StripLights_Pixel(86,0, color); // - - b b r r g g 
  StripLights_Pixel(87,0, color); // - - b b r r g g 
}

void wcNEUN (uint32 color)
{
  StripLights_Pixel(68,0, color); // - - b b r r g g 
  StripLights_Pixel(69,0, color); // - - b b r r g g 
  StripLights_Pixel(70,0, color); // - - b b r r g g 
  StripLights_Pixel(71,0, color); // - - b b r r g g 
}

void wcZEHN (uint32 color)
{
  StripLights_Pixel(52,0, color); // - - b b r r g g 
  StripLights_Pixel(53,0, color); // - - b b r r g g 
  StripLights_Pixel(54,0, color); // - - b b r r g g 
  StripLights_Pixel(55,0, color); // - - b b r r g g 
}

void wcELF (uint32 color)
{
  StripLights_Pixel(58,0, color); // - - b b r r g g 
  StripLights_Pixel(57,0, color); // - - b b r r g g 
  StripLights_Pixel(56,0, color); // - - b b r r g g 
  
}

void wcZWOELF (uint32 color)
{
  StripLights_Pixel(15,0, color); // - - b b r r g g 
  StripLights_Pixel(14,0, color); // - - b b r r g g 
  StripLights_Pixel(13,0, color); // - - b b r r g g 
  StripLights_Pixel(12,0, color); // - - b b r r g g 
  StripLights_Pixel(31,0, color); // - - b b r r g g 
}

void wcUHR (uint32 color)
{
  StripLights_Pixel(83,0, color); // - - b b r r g g 
  StripLights_Pixel(82,0, color); // - - b b r r g g 
  StripLights_Pixel(81,0, color); // - - b b r r g g 
}

void wcEINSMIN (uint32 color)
{
  StripLights_Pixel(67,0, color); // - - b b r r g g 
}

void wcZWEIMIN (uint32 color)
{
  StripLights_Pixel(66,0, color); // - - b b r r g g 
}

void wcDREIMIN (uint32 color)
{
  StripLights_Pixel(65,0, color); // - - b b r r g g 
}

void wcVIERMIN (uint32 color)
{
  StripLights_Pixel(64,0, color); // - - b b r r g g 
}

void wcMIN (uint32 color)
{
  StripLights_Pixel(50,0, color); // - - b b r r g g 
  StripLights_Pixel(49,0, color); // - - b b r r g g 
  StripLights_Pixel(48,0, color); // - - b b r r g g  
}

// This function will choose the right words to be displayed related to the current time information

void Anzeige ()
{
  //LedR_Write(~LedR_Read());
  
  StripLights_MemClear(StripLights_BLACK); // switch all elements off
  wcES(u32ColES);
  wcIST(u32ColIST);
  
  if(min==0)
  {
    wcGENAU(u32ColGENAU);
  }

  if ( ((min>=5) && (min<=9)) || ((min>=25) && (min<=29)) || ((min>=35) && (min<=39)) || ((min>=55) && (min<=59) ))
  {
    wcFUENFVOR(u32ColFUENFVOR);
  }

  if( ((min>=10) && (min<=14)) || ((min>=20) && (min<=24)) || ((min>=40) && (min<=44))|| ((min>=50) && (min<=54)) )
  {
    wcZEHNVOR(u32ColZEHNVOR);
  }
  
  if (((min>=15) && (min<=19)) || ((min>=45) && (min<=49)))
  {
   wcFUENFZEHNVOR(u32ColFUENFZEHNVOR);
  }
  
  if (((min>=45) && (min<=59)) || ((min>=20) && (min<=29)))
  {
    wcVOR(u32ColVOR);
  }
  
  if (((min>=5) && (min<=19)) || ((min>=35) && (min<=44)))
  {
    wcNACH(u32ColNACH);
  }
  
  if ( (min==30) || ((min>=20) && (min<=29)) || ((min>=31) && (min<=44)))
  {
    wcHALB(u32ColHALB);
  }

  if (((min>=20)  && (min<=59) && (hour ==11) ) || ((min<=19) && (hour==12)) )
  {
    wcZWOELF(u32ColZWOELF);
  }

  if ( ((min>=20)  && (min<=59) && (hour ==4) ) || ((min<=19) && (hour==5)))
  {
    wcFUENF(u32ColFUENF);
  }

  if (((min>=20)  && (min<=59) && (hour ==3) ) || ((min<=19) && (hour==4)))
  {
    wcVIER(u32ColVIER);
  }

  if (((min>=20)  && (min<=59) && (hour ==1) ) || ((min<=19) && (hour==2)))
  {
    wcZWEI(u32ColZWEI);
  }

  if (((min>=20)  && (min<=59) && (hour ==12) ) || ((min<=19) && (hour==1)))
  {
    wcEIN(u32ColEIN);
  }

  if (((min>=20)  && (min<=59) && (hour ==6) ) || ((min<=19) && (hour==7)))
  {
    wcSIEBEN(u32ColSIEBEN);
  }

  if  (((min>=20)  && (min<=59) && (hour ==2) ) || ((min<=19) && (hour==3)))
  {
    wcDREI(u32ColDREI);
  }

  if  (((min>=20)  && (min<=59) && (hour ==5) ) || ((min<=19) && (hour==6)))
  {
    wcSECHS(u32ColSECHS);
  }

  if (((min>=20)  && (min<=59) && (hour ==10) ) || ((min<=19) && (hour==11)))
  {
    wcELF(u32ColELF);
  }

  if (((min>=20)  && (min<=59) && (hour ==7) ) || ((min<=19) && (hour==8)))
  {
    wcACHT(u32ColACHT);
  }

  if (((min>=20)  && (min<=59) && (hour ==8) ) || ((min<=19) && (hour==9)))
  {
    wcNEUN(u32ColNEUN);
  }

  if (((min>=20)  && (min<=59) && (hour ==9) ) || ((min<=19) && (hour==10)))
  {
    wcZEHN(u32ColZEHN);
  }

  if ((min==1)  || (min==6) || (min==11) || (min==16) || (min==21) || (min==26) || (min==31) || (min==36) || (min==41) || (min==46) || (min==51) || (min==56))
  {
    wcEINSMIN(u32ColEINSMIN);
  }

  if ((min==2)  || (min==7) || (min==12) || (min==17) || (min==22) || (min==27) || (min==32) || (min==37) || (min==42) || (min==47) || (min==52) || (min==57))
  {
    wcZWEIMIN(u32ColZWEIMIN);
  }
   
  if ((min==3) || (min==8) || (min==13) || (min==18) || (min==23) || (min==28) || (min==33) || (min==38) || (min==43) || (min==48) || (min==53) || (min==58))
  {
    wcDREIMIN(u32ColDREIMIN);
  }
  
  if ((min==4) || (min==9) || (min==14) || (min==19) || (min==24) || (min==29) || (min==34) || (min==39) || (min==44) || (min==49) || (min==54) || (min==59))
  {
    wcVIERMIN(u32ColVIERMIN);
  }
   
  if ( (min==1) || (min==6) || (min==11) || (min==16) || (min==21) || (min==26) || (min==31) || (min==36) || (min==41) || (min==46) || (min==51) || (min==56) || (min==2) || (min==7) || (min==12) || (min==17) || (min==22) || (min==27) || (min==32) || (min==37) || (min==42) || (min==47) || (min==52) || (min==57) ||(min==3) || (min==8) || (min==13) || (min==18) || (min==23) || (min==28) || (min==33) || (min==38) || (min==43) || (min==48) || (min==53) || (min==58) || (min==4)|| (min==9) || (min==14) || (min==19) || (min==24) || (min==29) || (min==34) || (min==39) || (min==44) || (min==49) || (min==54) || (min==59))
  {
    wcMIN(u32ColMIN);
  }
  
  if ((min>=45) || (min<=19))
  {
    wcUHR(u32ColUHR);
  }
  
  if (( (min==30) || ((min>=20) && (min<=29)) || ((min>=31) && (min<=44))) && (hour==12))
  {
    wcS(u32ColEIN);
  }
}

/* ========================================
* BLE functions
* ========================================
*/

void UpdateBLEcharacteristic(uint8* pu8Data, uint8 u8DataLen, uint16 attrHandle) 
{ 
  /* 'rgbHandle' stores RGB control data parameters */ 

  CYBLE_GATT_HANDLE_VALUE_PAIR_T    rgbHandle; 

  /* Update RGB control handle with new values */ 

  rgbHandle.attrHandle = attrHandle; 
  rgbHandle.value.val = pu8Data; 
  rgbHandle.value.len = u8DataLen; 

  /* Update the RGB LED attribute value. This will allow  
  * Client device to read the existing color values over  
  * RGB LED characteristic */      

  CyBle_GattsWriteAttributeValue(&rgbHandle, FALSE, &cyBle_connHandle, CYBLE_GATT_DB_PEER_INITIATED); 
}

/* ========================================
* BLE EVENT HANDLER
* ========================================
*/

void GeneralEventHandler(uint32 event, void * eventParam) 
{ 
  uint8_t index;

  /* Structure to store data written by Client */   

  CYBLE_GATTS_WRITE_REQ_PARAM_T *wrReqParam; 

  switch(event) 
      { 
        /* HOWE requires Android 5, but functionality never tested
        case CYBLE_EVT_GATTC_XCHNG_MTU_RSP:
        // support larger MTU size (default 23)
        if(CYBLE_GATT_MTU > ((CYBLE_GATT_XCHG_MTU_PARAM_T *)eventParam)->mtu)
        {
          mtuSize = ((CYBLE_GATT_XCHG_MTU_PARAM_T *)eventParam)->mtu;
        }
        else
        {
          mtuSize = CYBLE_GATT_MTU;
        }
        CyBle_GattcExchangeMtuReq(cyBle_connHandle, CYBLE_GATT_MTU);
        break;
        */

        case CYBLE_EVT_STACK_ON: /* BLE stack is on. Start BLE advertisement */ 
  
             CyBle_GappStartAdvertisement(CYBLE_ADVERTISING_FAST); 
             break;  

        case CYBLE_EVT_GAP_DEVICE_DISCONNECTED: 

             /* This event is generated at GAP disconnection. */ 
             /* Register the new color in GATT DB*/       

             UpdateBLEcharacteristic(MyBleWordClockCalendar, sizeof(MyBleWordClockCalendar), CYBLE_CYWORDCLOCK_KALENDER_CHAR_HANDLE); 
             UpdateBLEcharacteristic(MyBleWordClockColor1, sizeof(MyBleWordClockColor1), CYBLE_CYWORDCLOCK_FARBSATZ1_CHAR_HANDLE);    
             UpdateBLEcharacteristic(MyBleWordClockColor2, sizeof(MyBleWordClockColor2), CYBLE_CYWORDCLOCK_FARBSATZ2_CHAR_HANDLE);    
             UpdateBLEcharacteristic(MyBleWordClockAlarm, sizeof(MyBleWordClockAlarm), CYBLE_CYWORDCLOCK_ALARMSETTING_CHAR_HANDLE);    

             /* Restart advertisement */ 
             CyBle_GappStartAdvertisement(CYBLE_ADVERTISING_FAST); 
             break;  

        case CYBLE_EVT_GAP_DEVICE_CONNECTED:

             UpdateBLEcharacteristic(MyBleWordClockCalendar, sizeof(MyBleWordClockCalendar), CYBLE_CYWORDCLOCK_KALENDER_CHAR_HANDLE); 
             UpdateBLEcharacteristic(MyBleWordClockColor1, sizeof(MyBleWordClockColor1), CYBLE_CYWORDCLOCK_FARBSATZ1_CHAR_HANDLE);    
             UpdateBLEcharacteristic(MyBleWordClockColor2, sizeof(MyBleWordClockColor2), CYBLE_CYWORDCLOCK_FARBSATZ2_CHAR_HANDLE);    
             UpdateBLEcharacteristic(MyBleWordClockAlarm, sizeof(MyBleWordClockAlarm), CYBLE_CYWORDCLOCK_ALARMSETTING_CHAR_HANDLE);    
             CyBle_GattsWriteRsp(cyBle_connHandle);
             break;

        case CYBLE_EVT_GATTS_WRITE_REQ: 

             /* Extract the Write data sent by Client */ 
             wrReqParam = (CYBLE_GATTS_WRITE_REQ_PARAM_T *) eventParam; 
  
             /* If the attribute handle of the characteristic written to  
              * is equal to that of RGB_LED characteristic, then extract  
              * the RGB LED data */   

             if(CYBLE_CYWORDCLOCK_KALENDER_CHAR_HANDLE == wrReqParam->handleValPair.attrHandle) 

             { 
               switch (wrReqParam->handleValPair.value.val[0])
               {
                 case 0 : /* Get BLE characteristic data: Time information */ 
                
                        MyBleWordClockCalendar[0] =  wrReqParam->handleValPair.value.val[0];
                        MyBleWordClockCalendar[1] =  wrReqParam->handleValPair.value.val[1]; 
                        MyBleWordClockCalendar[2] =  wrReqParam->handleValPair.value.val[2]; 
                        MyBleWordClockCalendar[3] =  wrReqParam->handleValPair.value.val[3]; 
                        MyBleWordClockCalendar[4] =  wrReqParam->handleValPair.value.val[4]; 
                        MyBleWordClockCalendar[5] =  wrReqParam->handleValPair.value.val[5]; 
                        MyBleWordClockCalendar[6] =  wrReqParam->handleValPair.value.val[6]; 
                        MyBleWordClockCalendar[7] =  wrReqParam->handleValPair.value.val[7]; 
                        MyBleWordClockCalendar[8] =  wrReqParam->handleValPair.value.val[8]; 
                        MyBleWordClockCalendar[9] =  wrReqParam->handleValPair.value.val[9]; 
                         
                        hour24 =  MyBleWordClockCalendar[1];
                        hour=hour24;
                        if (hour>=13)
                        {
                            hour=hour-12;
                        }  
                        
                        min  =  MyBleWordClockCalendar[2];
                        sec  =  MyBleWordClockCalendar[3];
                        day  =  MyBleWordClockCalendar[4];
                        u8ClockSet = 1;
                        UhrzeitUpdate = 1;

                        /* Update the GATT DB for RGB LED read characteristics*/ 
                        UpdateBLEcharacteristic(MyBleWordClockCalendar, sizeof(MyBleWordClockCalendar), CYBLE_CYWORDCLOCK_KALENDER_CHAR_HANDLE); 
                        flagLEDg = 1;
                        break;
                        
                 case 1 : // Restore preset color scheme
                        flagLEDg = 2;
                        ColorPresetRead(wrReqParam->handleValPair.value.val[1]);
                        UhrzeitUpdate = 1;
                        UpdateColor2BLE(); // Copy new colors to array used by BLE
                        UpdateBLEcharacteristic(MyBleWordClockCalendar, sizeof(MyBleWordClockCalendar), CYBLE_CYWORDCLOCK_KALENDER_CHAR_HANDLE);
                        UpdateBLEcharacteristic(MyBleWordClockColor1, sizeof(MyBleWordClockColor1), CYBLE_CYWORDCLOCK_FARBSATZ1_CHAR_HANDLE);
                        UpdateBLEcharacteristic(MyBleWordClockColor2, sizeof(MyBleWordClockColor2), CYBLE_CYWORDCLOCK_FARBSATZ2_CHAR_HANDLE);
                        break;
                        
                 case 2 : // Set new preset color scheme
                        flagLEDg = 3;
                        ColorPresetWrite(wrReqParam->handleValPair.value.val[1]);
                        break;
                        
                 case 3 : // Set all to one color
                        flagLEDg = 4;
                        for (index=0; index < CY_WORDCLOCK_COLOR_LEN1; index++)
                        {
                          MyBleWordClockColor1[index] =  wrReqParam->handleValPair.value.val[1]; 
                        }
                        for (index=0; index < CY_WORDCLOCK_COLOR_LEN2; index++)
                        {
                          MyBleWordClockColor2[index] =  wrReqParam->handleValPair.value.val[1]; 
                        }
                        UpdateBLE2Color(); // Change color table
                        UhrzeitUpdate = 1;
                        UpdateBLEcharacteristic(MyBleWordClockCalendar, sizeof(MyBleWordClockCalendar), CYBLE_CYWORDCLOCK_KALENDER_CHAR_HANDLE);
                        UpdateBLEcharacteristic(MyBleWordClockColor1, sizeof(MyBleWordClockColor1), CYBLE_CYWORDCLOCK_FARBSATZ1_CHAR_HANDLE);
                        UpdateBLEcharacteristic(MyBleWordClockColor2, sizeof(MyBleWordClockColor2), CYBLE_CYWORDCLOCK_FARBSATZ2_CHAR_HANDLE); 
                        break;
                        
                 case 4 : // Set dimming configuration
                        
                        u8DimMode = wrReqParam->handleValPair.value.val[1];
                        if (u8DimMode > 5)
                        {
                         u8DimMode = 4; // min brightness   
                        }
                        break;
                        
               }  
             } 

             if(CYBLE_CYWORDCLOCK_FARBSATZ1_CHAR_HANDLE == wrReqParam->handleValPair.attrHandle) 
             { 
               // flagLEDg = 2; // debug purpose
               /* Get BLE characteristic data: Color information */ 
               for (index=0; index < CY_WORDCLOCK_COLOR_LEN1; index++)
               {
                  MyBleWordClockColor1[index] =  wrReqParam->handleValPair.value.val[index]; 
               }
               UpdateBLE2Color(); // Change color table
               UhrzeitUpdate = 1;
               /* Update the GATT DB for RGB LED read characteristics*/ 
               UpdateBLEcharacteristic(MyBleWordClockCalendar, sizeof(MyBleWordClockCalendar), CYBLE_CYWORDCLOCK_KALENDER_CHAR_HANDLE);
               UpdateBLEcharacteristic(MyBleWordClockColor1, sizeof(MyBleWordClockColor1), CYBLE_CYWORDCLOCK_FARBSATZ1_CHAR_HANDLE);
               UpdateBLEcharacteristic(MyBleWordClockColor2, sizeof(MyBleWordClockColor2), CYBLE_CYWORDCLOCK_FARBSATZ2_CHAR_HANDLE); 
               UpdateBLEcharacteristic(MyBleWordClockAlarm, sizeof(MyBleWordClockAlarm), CYBLE_CYWORDCLOCK_ALARMSETTING_CHAR_HANDLE);    
             } 

             if(CYBLE_CYWORDCLOCK_FARBSATZ2_CHAR_HANDLE == wrReqParam->handleValPair.attrHandle) 
             { 
               // flagLEDg = 2; // debug purpose
               /* Get BLE characteristic data: Color information */ 
               for (index=0; index < CY_WORDCLOCK_COLOR_LEN2; index++)
               {
                   MyBleWordClockColor2[index] =  wrReqParam->handleValPair.value.val[index]; 
               }
               UpdateBLE2Color(); // Change color table
               UhrzeitUpdate = 1;
               /* Update the GATT DB for RGB LED read characteristics*/ 
               UpdateBLEcharacteristic(MyBleWordClockCalendar, sizeof(MyBleWordClockCalendar), CYBLE_CYWORDCLOCK_KALENDER_CHAR_HANDLE);
               UpdateBLEcharacteristic(MyBleWordClockColor1, sizeof(MyBleWordClockColor1), CYBLE_CYWORDCLOCK_FARBSATZ1_CHAR_HANDLE);
               UpdateBLEcharacteristic(MyBleWordClockColor2, sizeof(MyBleWordClockColor2), CYBLE_CYWORDCLOCK_FARBSATZ2_CHAR_HANDLE); 
               UpdateBLEcharacteristic(MyBleWordClockAlarm, sizeof(MyBleWordClockAlarm), CYBLE_CYWORDCLOCK_ALARMSETTING_CHAR_HANDLE);    
             } 

             if(CYBLE_CYWORDCLOCK_ALARMSETTING_CHAR_HANDLE == wrReqParam->handleValPair.attrHandle) 
             { 
               // flagLEDg = 2; // debug purpose
               /* Get BLE characteristic data: Color information */ 
               for (index=0; index < CY_WORDCLOCK_ALARM_LEN; index++)
               {
                   MyBleWordClockAlarm[index] =  wrReqParam->handleValPair.value.val[index]; 
               }
               UpdateBLEcharacteristic(MyBleWordClockCalendar, sizeof(MyBleWordClockCalendar), CYBLE_CYWORDCLOCK_KALENDER_CHAR_HANDLE);
               UpdateBLEcharacteristic(MyBleWordClockColor1, sizeof(MyBleWordClockColor1), CYBLE_CYWORDCLOCK_FARBSATZ1_CHAR_HANDLE);
               UpdateBLEcharacteristic(MyBleWordClockColor2, sizeof(MyBleWordClockColor2), CYBLE_CYWORDCLOCK_FARBSATZ2_CHAR_HANDLE); 
               UpdateBLEcharacteristic(MyBleWordClockAlarm, sizeof(MyBleWordClockAlarm), CYBLE_CYWORDCLOCK_ALARMSETTING_CHAR_HANDLE);    
             } 

            /* Send the response to the write request received. */ 
             CyBle_GattsWriteRsp(cyBle_connHandle);   

             break;

        default: // skip all other events
             flagLEDr = 0;
             break; 
    }      
}  

/* ========================================
 * Simple 1Hz Clock Real-Time-Watch Counter
 * ========================================
*/

void Clock1HzIsr()
{
    static uint16_t u16ADC; // keep the ambient light data
    
    sec=sec+1;
    if(sec >= 60)
    { 
        sec=0;
        min=min+1;
        
        // Check for alarm
        // depending on day(Monday=1 / Sunday=7), enabled alarm (hour.bit7) 
        if(
            ((day==1) && (MyBleWordClockAlarm[ 0]&0x80) && (((MyBleWordClockAlarm[ 0]&0x7F)==hour24)&& (MyBleWordClockAlarm[ 1]==min)))
         || ((day==2) && (MyBleWordClockAlarm[ 2]&0x80) && (((MyBleWordClockAlarm[ 2]&0x7F)==hour24)&& (MyBleWordClockAlarm[ 3]==min)))
         || ((day==3) && (MyBleWordClockAlarm[ 4]&0x80) && (((MyBleWordClockAlarm[ 4]&0x7F)==hour24)&& (MyBleWordClockAlarm[ 5]==min)))
         || ((day==4 )&& (MyBleWordClockAlarm[ 6]&0x80) && (((MyBleWordClockAlarm[ 6]&0x7F)==hour24)&& (MyBleWordClockAlarm[ 7]==min)))
         || ((day==5) && (MyBleWordClockAlarm[ 8]&0x80) && (((MyBleWordClockAlarm[ 8]&0x7F)==hour24)&& (MyBleWordClockAlarm[ 9]==min)))
         || ((day==6) && (MyBleWordClockAlarm[10]&0x80) && (((MyBleWordClockAlarm[10]&0x7F)==hour24)&& (MyBleWordClockAlarm[11]==min)))
         || ((day==7) && (MyBleWordClockAlarm[12]&0x80) && (((MyBleWordClockAlarm[12]&0x7F)==hour24)&& (MyBleWordClockAlarm[13]==min)))
        )
        {
           AlarmON=1; 
        }
        if (min==60)
        {
           min=0;
           hour=hour+1;
           hour24=hour24+1;
            
            if(hour==13)
            {
                hour=1;
            }
           
            if (hour24==24)
            {
                hour24=0;
                day=day+1;
            }
  
        }
        //UhrzeitUpdate=1;
      
    }
    
    if (u8DimMode < 5)                  // Manual brighness selection by App
    {
        StripLights_Dim(u8DimMode);
    }
    else
    {
        // Analyse the ambient light 
        
        if (ADC_IsEndConversion(ADC_RETURN_STATUS))
        {
            u16ADC = ADC_GetResult16(0) & 0xFF;
            
            #ifndef UART__DISABLED
                Uart_PutString("\rADC: ");
                itoa(u16ADC, szPrintf, 10);
                Uart_PutString(szPrintf);
            #endif
            
            #ifdef DEBUG_ADC_2_LED
              StripLights_MemClear(StripLights_BLACK); // switch all elements off
            #endif
            
            if (u8DimMode == 5)
            {
                if (u16ADC > u8LightDim1)
                {
                    #ifdef DEBUG_ADC_2_LED
                        wcVIERMIN(u32ColVIERMIN); // for debugging ADC
                    #endif
                    StripLights_Dim(1);
                }
                else
                if (u16ADC > u8LightDim2)
                {
                    #ifdef DEBUG_ADC_2_LED
                        wcDREIMIN(u32ColDREIMIN); // for debugging ADC
                    #endif
                    StripLights_Dim(2);
                    
                }
                else 
                if (u16ADC > u8LightDim3)
                {
                    #ifdef DEBUG_ADC_2_LED
                        wcZWEIMIN(u32ColZWEIMIN); // for debugging ADC
                    #endif
                    StripLights_Dim(3);
                }
                else
                { 
                    #ifdef DEBUG_ADC_2_LED
                        wcEINSMIN(u32ColZWEIMIN); // for debugging ADC
                    #endif
                    StripLights_Dim(4);    
                }
            } // if (u8DimMode == 5)

            ADC_StartConvert(); // Start next ADC used for ambint light
        }
    }

    #ifdef DEBUG_ADC_2_LED 
        if (CapsON)
        {
            wcES(u32ColZWEIMIN);
            CapsON = 0;    
        }
    #endif
    
    if (0 == u8ClockSet)
    {
        StripLights_MemClear(StripLights_BLACK); // switch all elements off
        if ((sec & 0x1) == 1)
        {
          wcUHR(0x0000FF00);   
        }
    }
    else
    {
        #ifndef DEBUG_ADC_2_LED 
          Anzeige();
        #endif
    }
    StripLights_Trigger(1);
    
    MyBleWordClockCalendar[1] =  hour; 
    MyBleWordClockCalendar[2] =  min; 
    MyBleWordClockCalendar[3] =  sec; 
    UpdateBLEcharacteristic(MyBleWordClockCalendar, sizeof(MyBleWordClockCalendar), CYBLE_CYWORDCLOCK_KALENDER_CHAR_HANDLE);
    
    CySysWdtClearInterrupt(CY_SYS_WDT_COUNTER0_INT);
}

#ifdef LED
/* ========================================
 * Debug Helper Functions
 * ========================================
*/

/* Will blink the Red LED for given cycles (blocking code) */
void BlinkR(uint8_t count)
{
    while (count)
    {
      //TPred_Write(1);
      LedR_Write(1);
      CyDelay(400);
      //TPred_Write(0);
      LedR_Write(0);
      CyDelay(200);
      count = count - 1;
    }
 }       

/* Will blink the Green LED for given cycles (blocking code) */
void BlinkG(uint8_t count)
{
    while (count)
    {
      //TPgreen_Write(1);
      LedG_Write(1);
      CyDelay(400);
      //TPgreen_Write(0);
      LedG_Write(0);
      CyDelay(200);
      count = count - 1;
    }
 }  
#endif

/* ========================================
 * INITIALIZE SYSTEM
 * ========================================
*/
void InitializeSystem(void)
{ 

    /* GPIO */

    /* ADC */

    ADC_Start();
    ADC_StartConvert();
    
    #ifndef DCF77__DISABLED
        DCF77_Start();
    #endif
    //PWM1_Start();

    #ifndef UART__DISABLED
    Uart_Start();
    Uart_PutString("\rCyWordClock");
    #endif
    
    u8DimMode   = 4;   // min brightness
    u8LightDim1 = 0xF0;
    u8LightDim2 = 0xC0;
    u8LightDim3 = 0x40;
} 

volatile uint16_t u16ADC;

/* ========================================
 * SysTick 100ms
 * ========================================
*/
uint32_t u32AlarmTick;

CY_ISR(mySystick_ISR)
{ 
  
    switch (AlarmON)
    {
        case 0 : // No Alarm
                 break; 
        case 1 : // Alarm initiated
                 CapSense_Start();  // Enable Proximity Sensor
                 CapSense_InitializeSensorBaseline(CapSense_SENSOR_PROXIMITYSENSOR0_0__PROX);
                 CapsON = 0;
                
                 PWM_Alarm_Start(); // Sound on
                 u32AlarmTick = 0;
                 AlarmON = 2;
                 break;
                
        case 2: // Wait
                u32AlarmTick = u32AlarmTick + 1;
                if ( CapsON || (u32AlarmTick >= 100) )
                {
                  AlarmON = 0; // Alarm off   
                  PWM_Alarm_Stop(); // Sound off
                
                  CapsON = 0;
                  CapSense_Stop();
                }
                break;
                
        default: // should never happen
                AlarmON = 0; // Alarm off   
                  PWM_Alarm_Stop(); // Sound off
    }
    
}

/* ========================================
 * M A I N
 * ========================================
*/        
int main(void)
{
    //BlinkR(1);
    //BlinkG(2);
    //BlinkR(1);
    
    // Start the components 
    InitializeSystem(); 
    CyGlobalIntEnable; /* Enable global interrupts. */
    
    Uart_Start();
    #ifndef DCF77__DISABLED
        Uart_PutString("DCF77 Example (Connect Signal to P1.0):\r");
    #endif
    
    //BLE  
    CyBle_Start(GeneralEventHandler); 

    // Initialize StripLights
    StripLights_Start();  

    // Set dim level 0 = full power, 4 = lowest power
    StripLights_Dim(u8DimMode); 
	
    // Clear all memory to black
    StripLights_MemClear(StripLights_BLACK);
    
    //Farben
    
    u32ColES           = 0x0000FF00;
    u32ColIST          = 0x000000FF;
    u32ColGENAU        = 0x00FF0000;
    u32ColFUENFVOR     = 0x00FFFFFF;
    u32ColZEHNVOR      = 0x00FFFFFF;
    u32ColFUENFZEHNVOR = 0x00FFFFFF,
    u32ColVOR          = 0x00FFFFFF;
    u32ColNACH         = 0x00FFFFFF;
    u32ColHALB         = 0x00FFFFFF;
    u32ColMIN          = 0x0000FF00;
    u32ColEINSMIN      = 0x00FFFFFF;
    u32ColZWEIMIN      = 0x00FFFFFF;
    u32ColDREIMIN      = 0x00FFFFFF;
    u32ColVIERMIN      = 0x00FFFFFF;
    u32ColUHR          = 0x000000FF;
        
    u32ColEIN          = 0x00FF0000;
    u32ColZWEI         = 0x000000FF;
    u32ColDREI         = 0x0000FF00;
    u32ColVIER         = 0x00FFFFFF;
    u32ColFUENF        = 0x00FFFFFF;
    u32ColSECHS        = 0x00FFFFFF;
    u32ColSIEBEN       = 0x00FFFFFF;
    u32ColACHT         = 0x00FFFFFF;
    u32ColNEUN         = 0x00FFFFFF;
    u32ColZEHN         = 0x00FFFFFF;
    u32ColELF          = 0x00FFFFFF;
    u32ColZWOELF       = 0x00FFFFFF;

    
    UpdateColor2BLE();
    
    // Predefined Alarm Settings
    MyBleWordClockAlarm[0] = 1;
    MyBleWordClockAlarm[1] = 1;
    MyBleWordClockAlarm[2] = 1;
    MyBleWordClockAlarm[3] = 1;
    MyBleWordClockAlarm[4] = 1;
    MyBleWordClockAlarm[5] = 1;
    MyBleWordClockAlarm[6] = 1;
    MyBleWordClockAlarm[7] = 1;
    MyBleWordClockAlarm[8] = 1;
    MyBleWordClockAlarm[9] = 1;
    MyBleWordClockAlarm[10] = 1;
    MyBleWordClockAlarm[11] = 1;
    MyBleWordClockAlarm[12] = 1;
    MyBleWordClockAlarm[13] = 1;
    
    // aktuelle Uhrzeit 
     
    u8ClockSet = 0;
    hour =  9;
    min  =  31;
    sec  =  0;
    
    MyBleWordClockCalendar[1] =  hour; 
    MyBleWordClockCalendar[2] =  min; 
    MyBleWordClockCalendar[3] =  sec; 
    
   UhrzeitUpdate=0 ;

   CapsON = 0;
   
   // 1Hz Clock
   //CySysWdtSetInterruptCallback(CY_SYS_WDT_COUNTER0, Clock1HzIsr);
   isr_wdt_StartEx(Clock1HzIsr);
   CySysWdtEnable(CY_SYS_WDT_COUNTER0);
 
    // SysTick
    /* Map systick ISR to the user defined ISR. SysTick_IRQn is already defined in core_cm0.h file */
    CyIntSetSysVector((SysTick_IRQn + 16), mySystick_ISR);
	
    SysTick_Config(NUMBER_OF_TICKS); // e.g.: 12000 -> Enable Systick timer with desired period/number of ticks tick = t * f(mainclock)
    
    /*wcFUENFVOR(0x0000FF00); //rot
    wcVOR(0x000000FF); //grün
    wcZWOELF(0x00FF0000); //blau
    wcVIER(0x00FFFFFF); //weis
    wcEIN(0x0000FFFF); //rotgrün
    wcDREI(0x00FFFF00); //rotblau
    wcELF(0x00FF00FF); //grünblau
    */
  //Anzeige();
    /*
    StripLights_Pixel(0,0, 0x00FF0000); // - - b b r r g g 
    StripLights_Pixel(15,0,0x00110000); // - - b b r r g g 
    StripLights_Pixel(16,0, 0x0000FF00); // - - b b r r g g 
    StripLights_Pixel(17,0, 0x00008800); // - - b b r r g g 
    StripLights_Pixel(31,0, 0x00001100); // - - b b r r g g 
    StripLights_Pixel(32,0, 0x000000FF); // - - b b r r g g 
    StripLights_Pixel(56,0, 0x00333333); // - - b b r r g g 
    StripLights_Pixel(63,0, 0x00000011); // - - b b r r g g 
    StripLights_Trigger(1); 
    */
    CyDelay(100); 
    
    // CAPSENSE / PROXIMITY
    
    /* 1. Enable Proximity sensor as it is disabled by default */
  
    AlarmON=1;
    
   // while(1);
    
	for(;;)
	{
        CyBle_ProcessEvents(); 

        /* Process input side - Proximity sensor */
        /* Check if CapSense block is busy or not and enable the next scan accordingly */
        
        if (AlarmON > 1) 
        {
            if (CapSense_IsBusy() == 0)
            {
                // Update proximity sensor baseline
                CapSense_UpdateSensorBaseline(CapSense_SENSOR_PROXIMITYSENSOR0_0__PROX);

                // Check if proximity sensor is active - thresholds are dynamically calculated during run-time
                // proximityActive variable will have a non-zero value if Proximity was active
                if (CapSense_CheckIsSensorActive(CapSense_SENSOR_PROXIMITYSENSOR0_0__PROX))
                {
                   CapsON = 1;   
                }
            
                CapSense_ScanSensor(CapSense_SENSOR_PROXIMITYSENSOR0_0__PROX);
            }
        }
    
        #ifndef DCF77__DISABLED
        // Check DCF77 module
        
        if (DCF77_Get_Time(&hour24, &min))
        {
            DCF77_Clear_Data();
            hour=hour24;
            if (hour>=13)
            {
              hour=hour-12;
            } 
            u8ClockSet    = 1;
            UhrzeitUpdate = 1;
        }
        #endif
    
    } // for
} 

/* [] END OF FILE */
